## MeDIL
MeDIL is a Python package for causal modeling, originally focusing on the measurement dependence inducing latent (MeDIL) causal model framework[<sup>1</sup>](#uai_paper), but now including more general methods for causal discovery and inference.

More information can be found in the [documentation](https://medil.causal.dev).

### Support, Bugs, and Contributing
If you have any questions, suggestions, feedback, or bugs to report, please [open an issue on Gitlab](https://gitlab.com/alex-markham/medil/issues/new) or [on Github](https://github.com/Alex-Markham/medil/issues/new) or [contact me](https://causal.dev/#contact).
Additionally, if you would like to use this package or any of its code in your research, or to contribute to this package, feel free (but not obliged) to [contact me](https://causal.dev/#contact).

### License
See [LICENSE](https://gitlab.com/alex-markham/medil/blob/master/LICENSE.txt), which is the Cooperative Non-Violent Public License v7 or later (CNPLv7+).

#### Brief License Summary (For Lay-People)

The Nonviolent Public License aims to ensure basic protections against forms of violence, coercion, and discrimination.
This license covers several formats of creative work but has extra terms for software given the power it has as a tool outside of its creative capacities.
The Cooperative Nonviolent Public License goes further to only allow commercial use of the copyrighted work for individuals and worker-owned organizations. 

### Changelog
See [CHANGELOG](https://gitlab.com/alex-markham/medil/blob/master/CHANGELOG.md) for a history of the already implemented features, works in progress, and future feature ideas.

### References
<a name="uai_paper"> 1.</a> Markham, Alex & Grosse-Wentrup, Moritz. (2020). Measurement Dependence Inducing Latent Causal Models. In *Conference on Uncertainty in Artificial Intelligence (UAI)* PMLR 124:590&ndash;599. URL: [http://proceedings.mlr.press/v124/markham20a/markham20a.pdf](http://proceedings.mlr.press/v124/markham20a/markham20a.pdf)
